@@ -13,10 +13,10 @@ Modified by Markus Enzenberger <enz@cip.physik.uni-muenchen.de>.
 Copyright of the modifications 1998.
 Modified by Cornelius Krasel <krasel@wpxx02.toxi.uni-wuerzburg.de>.
 Copyright of the modifications 1998, 1999.
-Modified by Matthias Andree <matthias.andree@gmx.de>.
-Copyright of the modifications 1999 - 2002.
 Modified and copyright of the modifications 2002 by Ralf Wildenhues
 <ralf.wildenhues@gmx.de>.
+Modified by Matthias Andree <matthias.andree@gmx.de>.
+Copyright of the modifications 1999 - 2021.
 
 See file COPYING for restrictions on the use of this software.
 */
@@ -578,7 +578,7 @@ findinlist(struct stringlist *haystack, char *needle)
     struct stringlist *a;
 
     a = haystack;
-    while (a && a->string) {
+    while (a && *a->string) {
 	if (strncmp(needle, a->string, strlen(needle)) == 0)
 	    return a->string;
 	a = a->next;
@@ -596,7 +596,7 @@ lfindinlist(struct stringlist **haystack, char *needle, size_t len)
     struct stringlist **a;
 
     a = haystack;
-    while (a && *a && (*a)->string) {
+    while (a && *a && *(*a)->string) {
 	if (strncmp(needle, (*a)->string, len) == 0)
 	    return a;
 	a = &(*a)->next;
