@@ -14,12 +14,12 @@ Copyright of the modifications 1998.
 Modified by Cornelius Krasel <krasel@wpxx02.toxi.uni-wuerzburg.de>
 and Kazushi (Jam) Marukawa <jam@pobox.com>.
 Copyright of the modifications 1998, 1999.
-Modified by Matthias Andree <matthias.andree@gmx.de>
-Copyright of the modifications 2000 - 2002.
 Modified by Ralf Wildenhues <ralf.wildenhues@gmx.de>
 Copyright of the modifications 2002.
 Modified by Jonathan Larmour <jifl@jifvik.org>
 Copyright of the modifications 2002.
+Modified by Matthias Andree <matthias.andree@gmx.de>
+Copyright of the modifications 2000 - 2021.
 
 See file COPYING for restrictions on the use of this software.
 */
@@ -1121,7 +1121,9 @@ dopost(void)
 		havemessageid = TRUE;
 		if (debugmode)
 		    syslog(LOG_DEBUG, "debug header: %s", line);
-		if (2 != (rc = pcre_extract(line, "Message-ID:\\s+<(?:[^>]+)@([^@>]+)>\\s*$", vec, 2))
+		if (2 != (rc = ln_pcre_extract((unsigned char *)line,
+					       (unsigned char *)"Message-ID:\\s+<(?:[^>]+)@([^@>]+)>\\s*$",
+					       vec, 2))
 			|| vec[1] == NULL) {
 		    ferr = TRUE, ferrstr = "Malformatted Message-ID: header.";
 		} else if (!strchr(vec[1], '.')) {
@@ -1129,7 +1131,7 @@ dopost(void)
 		} else if (!is_validfqdn(vec[1])) {
 		    ferr = TRUE, ferrstr = "Message-ID: header contains invalid domain name part.";
 		}
-		pcre_extract_free(vec, rc);
+		ln_pcre_extract_free(vec, rc);
 	    }
 	}
 	if (!strncasecmp(line, "Subject: ", 9)) {
